@@ -10,8 +10,10 @@ test_that("Error for unsupported file types", {
     writeLines("123", con = "test.faketype")
     expect_error(import("test.faketype"), "Unrecognized file format")
     expect_error(export(mtcars, "mtcars.faketype"), "Unrecognized file format")
-    expect_error(get_type("faketype"), "Unrecognized file format. Try specifying with the format argument.")
+    expect_message(get_type("faketype"), "Unrecognized file format. Try specifying with the format argument.")
+    expect_equal(get_type("faketype"), "faketype")
     expect_error(get_ext("noextension"), "'file' has no extension")
+    unlink("test.faketype")
 })
 
 test_that("Error for mixed support file types", {
@@ -21,9 +23,10 @@ test_that("Error for mixed support file types", {
 })
 
 test_that("Only export data.frame or matrix", {
-    expect_error(export(1, "test.csv"), "`x` is not a data.frame or matrix")
+    expect_error(export(1, "test.csv"), "'x' is not a data.frame or matrix")
 })
 
 test_that("Column widths printed for fixed-width format", {
     expect_message(export(data.frame(1), "test.txt", format = "fwf"))
+    unlink("test.txt")
 })
